<?php

namespace FiloBlu\Adminordergrid\Console;
use Symfony\Component\Console\Command\Command;
use Symfony\Component\Console\Input\InputInterface;
use Symfony\Component\Console\Output\OutputInterface;
use Symfony\Component\Console\Helper\ProgressBar;

class HppSyncCommand extends Command
{
    
    /**
     *
     * @var \Magento\Framework\App\ResourceConnection
     */
    private $resource;

    /**
     * Constructor
     */
    public function __construct(
            \Magento\Framework\App\ResourceConnection $resource
            )
    {
        $this->resource = $resource;
        parent::__construct();
    }
 
    protected function configure()
    {
        $this->setName('filoblu:adminordergrid:hppsync')->setDescription('Sync order grid with payment details from HPP payments');
    }
 
    protected function execute(InputInterface $input, OutputInterface $output)
    {
        /** @var $connection Magento\Framework\DB\Adapter\Pdo\Mysql */
        $connection = $this->resource->getConnection(\Magento\Framework\App\ResourceConnection::DEFAULT_CONNECTION);
        $salesOrderPaymentTable = $connection->getTableName('sales_order_payment');
        $payments = $connection->fetchAll('SELECT * FROM `'.$salesOrderPaymentTable.'` WHERE method = "adyen_hpp" AND cc_type IS NULL');
        $row_to_update = array();
        foreach ($payments as $payment) {
            $additional_information = unserialize($payment['additional_information']);
            if (isset($additional_information['brand_code'])) {
                $row_to_update[] = array('order_id' => $payment['parent_id'], 'brand_code' => $additional_information['brand_code']);
            }
        }
        
        $progress = new ProgressBar($output, count($row_to_update));
                
        foreach ($row_to_update as $row) {
            $connection->update(
                    $connection->getTableName('sales_order_payment'), 
                    array('cc_type' => $row['brand_code']), 
                    'parent_id = ' . $row['order_id']
                    );
            $connection->update(
                    $connection->getTableName('sales_order_grid'), 
                    array('payment_cctype' => $row['brand_code']), 
                    'entity_id = ' . $row['order_id']
                    );
            $progress->advance(1);
        }
        $progress->finish();
        $output->writeln('');
        $output->writeln(count($row_to_update) . ' orders were processed');
    }
 
}